M/EEG Microstates
------------------

Main
^^^^^^^^^^^^^^^^
*microstates_segment()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_segment

*microstates_plot()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_plot

*microstates_classify()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_classify

*microstates_clean()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_clean

*microstates_dynamic()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_dynamic

*microstates_findnumber()*
"""""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_findnumber

*microstates_peaks()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_peaks

*microstates_static()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.microstates.microstates_static